@@ -27,9 +27,9 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2007 ImageMagick Studio LLC"
-#define MagickLibVersion  0x632
-#define MagickLibVersionText  "6.3.2"
-#define MagickLibVersionNumber  6,3,2,1
+#define MagickLibVersion  0x634
+#define MagickLibVersionText  "6.3.4"
+#define MagickLibVersionNumber  6,3,4,1
 #if (QuantumDepth == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -46,10 +46,15 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "03/12/07"
+#define MagickReleaseDate  "09/02/07"
+#if !defined(UseHDRI)
 #define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " " MagickHomeURL
-#define MagickHomeURL  "http://www.imagemagick.org"
+  MagickReleaseDate " " MagickQuantumDepth " http://www.imagemagick.org"
+#else
+#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
+  MagickReleaseDate " " MagickQuantumDepth " HDRI http://www.imagemagick.org"
+#endif
+#define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 
 extern MagickExport char
   *GetMagickHomeURL(void);
